@@ -8,7 +8,7 @@
 #ifndef SOUNDIO_SOUNDIO_H
 #define SOUNDIO_SOUNDIO_H
 
-#include "config.h"
+#include "endian.h"
 #include <stdbool.h>
 
 /// \cond
@@ -18,14 +18,18 @@
 #define SOUNDIO_EXTERN_C
 #endif
 
-#if defined(_WIN32)
-#if defined(SOUNDIO_BUILDING_LIBRARY)
-#define SOUNDIO_EXPORT SOUNDIO_EXTERN_C __declspec(dllexport)
+#if defined(SOUNDIO_STATIC_LIBRARY)
+# define SOUNDIO_EXPORT SOUNDIO_EXTERN_C
 #else
-#define SOUNDIO_EXPORT SOUNDIO_EXTERN_C __declspec(dllimport)
-#endif
-#else
-#define SOUNDIO_EXPORT SOUNDIO_EXTERN_C __attribute__((visibility ("default")))
+# if defined(_WIN32)
+#  if defined(SOUNDIO_BUILDING_LIBRARY)
+#   define SOUNDIO_EXPORT SOUNDIO_EXTERN_C __declspec(dllexport)
+#  else
+#   define SOUNDIO_EXPORT SOUNDIO_EXTERN_C __declspec(dllimport)
+#  endif
+# else
+#  define SOUNDIO_EXPORT SOUNDIO_EXTERN_C __attribute__((visibility ("default")))
+# endif
 #endif
 /// \endcond
 
@@ -669,7 +673,14 @@ struct SoundIoInStream {
     int layout_error;
 };
 
-// Main Context
+/// See also ::soundio_version_major, ::soundio_version_minor, ::soundio_version_patch
+SOUNDIO_EXPORT const char *soundio_version_string(void);
+/// See also ::soundio_version_string, ::soundio_version_minor, ::soundio_version_patch
+SOUNDIO_EXPORT int soundio_version_major(void);
+/// See also ::soundio_version_major, ::soundio_version_string, ::soundio_version_patch
+SOUNDIO_EXPORT int soundio_version_minor(void);
+/// See also ::soundio_version_major, ::soundio_version_minor, ::soundio_version_string
+SOUNDIO_EXPORT int soundio_version_patch(void);
 
 /// Create a SoundIo context. You may create multiple instances of this to
 /// connect to multiple backends. Sets all fields to defaults.
@@ -914,8 +925,9 @@ SOUNDIO_EXPORT struct SoundIoOutStream *soundio_outstream_create(struct SoundIoD
 /// You may not call this function from the SoundIoOutStream::write_callback thread context.
 SOUNDIO_EXPORT void soundio_outstream_destroy(struct SoundIoOutStream *outstream);
 
-/// After you call this function, SoundIoOutStream:software_latency is set to the correct
-/// value.
+/// After you call this function, SoundIoOutStream::software_latency is set to
+/// the correct value.
+///
 /// The next thing to do is call ::soundio_instream_start.
 /// If this function returns an error, the outstream is in an invalid state and
 /// you must call ::soundio_outstream_destroy on it.
@@ -939,6 +951,8 @@ SOUNDIO_EXPORT int soundio_outstream_open(struct SoundIoOutStream *outstream);
 
 /// After you call this function, SoundIoOutStream::write_callback will be called.
 ///
+/// This function might directly call SoundIoOutStream::write_callback.
+///
 /// Possible errors:
 /// * #SoundIoErrorStreaming
 /// * #SoundIoErrorNoMem
@@ -1005,14 +1019,15 @@ SOUNDIO_EXPORT int soundio_outstream_end_write(struct SoundIoOutStream *outstrea
 /// * #SoundIoErrorIncompatibleDevice
 SOUNDIO_EXPORT int soundio_outstream_clear_buffer(struct SoundIoOutStream *outstream);
 
-/// If the underlying device supports pausing, this pauses the stream.
-/// SoundIoOutStream::write_callback may be called a few more times if the
-/// buffer is not full.
+/// If the underlying backend and device support pausing, this pauses the
+/// stream. SoundIoOutStream::write_callback may be called a few more times if
+/// the buffer is not full.
 /// Pausing might put the hardware into a low power state which is ideal if your
 /// software is silent for some time.
-/// This function may be called from any thread.
+/// This function may be called from any thread context, including
+/// SoundIoOutStream::write_callback.
 /// Pausing when already paused or unpausing when already unpaused has no
-/// effect and always returns SoundIoErrorNone.
+/// effect and returns #SoundIoErrorNone.
 ///
 /// Possible errors:
 /// * #SoundIoErrorBackendDisconnected
@@ -1020,6 +1035,8 @@ SOUNDIO_EXPORT int soundio_outstream_clear_buffer(struct SoundIoOutStream *outst
 /// * #SoundIoErrorIncompatibleDevice - device does not support
 ///   pausing/unpausing. This error code might not be returned even if the
 ///   device does not support pausing/unpausing.
+/// * #SoundIoErrorIncompatibleBackend - backend does not support
+///   pausing/unpausing.
 /// * #SoundIoErrorInvalid - outstream not opened and started
 SOUNDIO_EXPORT int soundio_outstream_pause(struct SoundIoOutStream *outstream, bool pause);
 
@@ -1123,7 +1140,7 @@ SOUNDIO_EXPORT int soundio_instream_end_read(struct SoundIoInStream *instream);
 /// #SoundIoErrorIncompatibleDevice.
 /// This function may be called from any thread.
 /// Pausing when already paused or unpausing when already unpaused has no
-/// effect and always returns SoundIoErrorNone.
+/// effect and always returns #SoundIoErrorNone.
 ///
 /// Possible errors:
 /// * #SoundIoErrorBackendDisconnected
